==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TileGeneratorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let TileGeneratorDescriptionMetadata = /*@__PURE__*/ (() => {
    class TileGeneratorDescriptionMetadata extends Base {
        static b(a) {
            if (TileGeneratorDescriptionMetadata.a == null) {
                TileGeneratorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TileGeneratorDescriptionMetadata.c(TileGeneratorDescriptionMetadata.a);
            }
            if (a.k(TileGeneratorDescriptionMetadata.a)) {
                return;
            }
            a.aa(TileGeneratorDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            TileGeneratorDescriptionMetadata.b(a);
            a.ab("TileGenerator", TileGeneratorDescriptionMetadata.a);
        }
    }
    TileGeneratorDescriptionMetadata.$t = /*@__PURE__*/ markType(TileGeneratorDescriptionMetadata, 'TileGeneratorDescriptionMetadata');
    TileGeneratorDescriptionMetadata.a = null;
    return TileGeneratorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/TileGeneratorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let TileGeneratorDescriptionMetadata = /*@__PURE__*/ (() => {
    class TileGeneratorDescriptionMetadata extends Base {
        static b(a) {
            if (TileGeneratorDescriptionMetadata.a == null) {
                TileGeneratorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TileGeneratorDescriptionMetadata.c(TileGeneratorDescriptionMetadata.a);
            }
            if (a.k(TileGeneratorDescriptionMetadata.a)) {
                return;
            }
            a.ac(TileGeneratorDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            TileGeneratorDescriptionMetadata.b(a);
            a.ad("TileGenerator", TileGeneratorDescriptionMetadata.a);
        }
    }
    TileGeneratorDescriptionMetadata.$t = /*@__PURE__*/ markType(TileGeneratorDescriptionMetadata, 'TileGeneratorDescriptionMetadata');
    TileGeneratorDescriptionMetadata.a = null;
    return TileGeneratorDescriptionMetadata;
})();
